@@ -5,19 +5,13 @@ from ninja.constants import NOT_SET
 from ninja.signature import is_async
 from ninja.types import TCallable
 
+from ninja_extra.constants import DELETE, GET, PATCH, POST, PUT, ROUTE_METHODS
 from ninja_extra.controllers.response import ControllerResponse
 from ninja_extra.permissions import BasePermission
 from ninja_extra.schemas import RouteParameter
 
 from .route_functions import AsyncRouteFunction, RouteFunction
 
-POST = "POST"
-PUT = "PUT"
-PATCH = "PATCH"
-DELETE = "DELETE"
-GET = "GET"
-ROUTE_METHODS = [POST, PUT, PATCH, DELETE, GET]
-
 
 class RouteInvalidParameterException(Exception):
     pass
@@ -459,8 +453,7 @@ class Route(object):
 
         _response = response
         if (
-            inspect.isclass(response)
-            and issubclass(response, ControllerResponse)  # type:ignore
+            inspect.isclass(response) and issubclass(response, ControllerResponse)
         ) or isinstance(response, ControllerResponse):
             response = cast(ControllerResponse, response)
             _response = {response.status_code: response.get_schema()}
